<?php

namespace FiloBlu\CustomerBlocker\Observer\Sales;
use Exception;
use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Message\ManagerInterface;
use Psr\Log\LoggerInterface;
use FiloBlu\CustomerBlocker\Helper\DataHelper;
use Throwable;

class OrderPlaceBeforeAbstract implements ObserverInterface {

    protected $messageManager;
    protected $helper;
    /**
     * @var LoggerInterface
     */
    private $logger;

    /**
     * OrderPlaceBeforeAbstract constructor.
     * @param ManagerInterface $messageManager
     * @param DataHelper $helper
     * @param LoggerInterface $logger
     */
    public function __construct(
        ManagerInterface $messageManager,
        DataHelper $helper,
        LoggerInterface $logger
    ) {
        $this->messageManager = $messageManager;
        $this->helper = $helper;
        $this->logger = $logger;
    }

    /**
     * @param Observer $observer
     * @param false $isPayPalOrder
     * @return bool
     */
    protected function checkCustomerAddress(Observer $observer, $isPayPalOrder = false)
    {
        try{
            // Get order data based on payment method
            if($isPayPalOrder)
            {
                $quote = $observer->getEvent()->getQuote();
                if($quote->isVirtual()){
                    $data = $quote->getBillingAddress()->getData();
                }else{
                    $data = $quote->getShippingAddress()->getData();
                }
            }
            else
            {
                $order = $observer->getEvent()->getOrder();
                if($order->getIsVirtual()){
                    $data = $order->getBillingAddress()->getData();
                }else{
                    $data = $order->getShippingAddress()->getData();
                }

            }
            return $this->helper->isAddressToBeBlocked($data);
        }catch (Exception $e){
            $this->logger->critical($e->getMessage());
            return false;
        }catch (Throwable $t){
            $this->logger->critical($t->getMessage());
            return false;
        }

    }

    /**
     * @param Observer $observer
     */
    public function execute(Observer $observer) {

    }

}